@@ -86,7 +86,7 @@ void print_help (const char* progname)
 {
   puts (_("Usage:"));
   printf ("%s -h|v   %s\n\n", progname, _("or"));
-  printf ("%s %s\n", progname, _("[-a maxerr][-r maxerr][-2][-P][-N][-s ifs][-b][-q][-D][-E][-I][-S][-# prec][-d c1c2][-t c1c2][-g n1n2][-p c1c2][-n c1c2][-e c1c2][-i c1c2][-F f1-f2][-L l1-l2][-l path][-o path] FILE1 FILE2"));
+  printf ("%s %s\n", progname, _("[-a maxerr][-r maxerr][-2][-P][-N][-s ifs][-b][-V][-q][-D][-E][-I][-S][-# prec][-d c1c2][-t c1c2][-g n1n2][-p c1c2][-n c1c2][-e c1c2][-i c1c2][-F f1-f2][-L l1-l2][-l path][-o path] FILE1 FILE2"));
   /* %%% */
   printf (_("\nCompare putatively similar files line by line and field by field,\nignoring small numeric differences or/and different numeric formats\n\n"));
   printf ("-a maxerr %s\n          %s\n", 
@@ -112,6 +112,8 @@ void print_help (const char* progname)
 	  _("(The default set of characters is white space, tab and newline)"));
   printf ("-b        %s\n",
 	  _("Suppress all messages concerning the differences discovered\n\t  in the structures of the two files"));
+  printf ("-V        %s\n",
+	  _("For every line differing in at least one field print an header\n\t  to show how this line appears in the two compared files"));
   printf ("-q        %s\n",
 	  _("Suppress all the standard output"));
   printf ("-S        %s\n",
@@ -385,7 +387,7 @@ extern int optind;
 
 int setargs (int argc, char* argv[], argslist *list)
 {
-  const char *optstring = "h2bqDESIPN#:s:a:r:d:t:g:p:n:e:i:F:L:l:o:v";
+  const char *optstring = "h2bVqDESIPN#:s:a:r:d:t:g:p:n:e:i:F:L:l:o:v";
   char *tail;
   int optch, i; 
   struct numfmt defaults;
@@ -449,6 +451,9 @@ int setargs (int argc, char* argv[], argslist *list)
 	case 'b':
 	  list->optmask |= _B_MASK;
 	  break;
+	case 'V':
+	  list->optmask |= _SV_MASK;
+	  break;
 	case 'q':
 	  list->optmask |= _Q_MASK;
 	  break;
